pub enum JoinType {
Inner,
Left,
Right,
Full,
Cross,
}Variants
Implementations
Sourceimpl JoinType
impl JoinType
pub fn is_equi(&self) -> bool
pub fn is_semi_anti(&self) -> bool
pub fn is_semi(&self) -> bool
pub fn is_anti(&self) -> bool
pub fn is_asof(&self) -> bool
pub fn is_inner(&self) -> bool
pub fn is_cross(&self) -> bool
pub fn is_ie(&self) -> bool
pub fn is_range(&self) -> bool
Sourcepub fn emits_unmatched_left(&self) -> bool
pub fn emits_unmatched_left(&self) -> bool
Unmatched rows of the left input appear in the output.
Sourcepub fn emits_unmatched_right(&self) -> bool
pub fn emits_unmatched_right(&self) -> bool
Unmatched rows of the right input appear in the output.
Sourcepub fn supports_non_equi(&self) -> bool
pub fn supports_non_equi(&self) -> bool
Joins supported in join where with non-equi conditions
Sourcepub fn supports_non_equi_options(
&self,
options: &Option<JoinTypeOptions>,
) -> bool
pub fn supports_non_equi_options( &self, options: &Option<JoinTypeOptions>, ) -> bool
Whether the physical join implementations can execute this how with the given
(already-resolved) match-condition algorithm without silently dropping it.