pub trait GatherDf {
// Required methods
fn gather_with_column(
&self,
idxs: &Column,
null_on_oob: bool,
) -> PolarsResult<DataFrame>;
fn gather_with_series(
&self,
idxs: &Series,
null_on_oob: bool,
) -> PolarsResult<DataFrame>;
}Required Methods
Sourcefn gather_with_column(
&self,
idxs: &Column,
null_on_oob: bool,
) -> PolarsResult<DataFrame>
fn gather_with_column( &self, idxs: &Column, null_on_oob: bool, ) -> PolarsResult<DataFrame>
Selects from this DataFrame the rows at the indices in the given column.
Sourcefn gather_with_series(
&self,
idxs: &Series,
null_on_oob: bool,
) -> PolarsResult<DataFrame>
fn gather_with_series( &self, idxs: &Series, null_on_oob: bool, ) -> PolarsResult<DataFrame>
Selects from this DataFrame the rows at the indices in the given series.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".